==> jena-5.3.0-source-release.zip: jena-5.3.0/jena-arq/src/test/java/org/apache/jena/riot/TestParserRegistry.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.riot;

import org.junit.Assert;

import org.junit.Test;

/**
 * Tests for the {@link RDFParserRegistry}
 *
 */
public class TestParserRegistry {

    @Test
    public void parser_registry_is_triples() {
        Assert.assertTrue(RDFParserRegistry.isTriples(RDFLanguages.N3));
        Assert.assertTrue(RDFParserRegistry.isTriples(RDFLanguages.NTRIPLES));
        Assert.assertTrue(RDFParserRegistry.isTriples(RDFLanguages.TURTLE));
        Assert.assertTrue(RDFParserRegistry.isTriples(RDFLanguages.RDFXML));
        Assert.assertTrue(RDFParserRegistry.isTriples(RDFLanguages.RDFJSON));
    }
    
    @Test
    public void parser_registry_is_quads() {
        Assert.assertTrue(RDFParserRegistry.isQuads(RDFLanguages.NQUADS));
        Assert.assertTrue(RDFParserRegistry.isQuads(RDFLanguages.TRIG));
    }

}

==> jena-5.6.0-source-release.zip: jena-5.6.0/jena-arq/src/test/java/org/apache/jena/riot/TestParserRegistry.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.riot;

import static org.junit.jupiter.api.Assertions.assertTrue;

import org.junit.jupiter.api.Test;

/**
 * Tests for the {@link RDFParserRegistry}
 */
public class TestParserRegistry {
    @Test
    public void parser_registry_is_triples() {
        assertTrue(RDFParserRegistry.isTriples(RDFLanguages.N3));
        assertTrue(RDFParserRegistry.isTriples(RDFLanguages.NTRIPLES));
        assertTrue(RDFParserRegistry.isTriples(RDFLanguages.TURTLE));
        assertTrue(RDFParserRegistry.isTriples(RDFLanguages.RDFXML));
        assertTrue(RDFParserRegistry.isTriples(RDFLanguages.RDFJSON));
    }

    @Test
    public void parser_registry_is_quads() {
        assertTrue(RDFParserRegistry.isQuads(RDFLanguages.NQUADS));
        assertTrue(RDFParserRegistry.isQuads(RDFLanguages.TRIG));
    }
}
